epistoch package
================


Submodules
----------


epistoch.seird\_ph module
-------------------------

.. automodule:: epistoch.seird_ph
    :members:
    :undoc-members:
    :show-inheritance:

epistoch.sir\_g module
----------------------

.. automodule:: epistoch.sir_g
    :members:
    :undoc-members:
    :show-inheritance:

epistoch.sir\_phg module
------------------------

.. automodule:: epistoch.sir_phg
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: epistoch
    :members:
    :undoc-members:
    :show-inheritance:
